@@ -1,5 +1,6 @@
 import logging
 from functools import wraps
+from inspect import getfullargspec
 from json import loads
 from traceback import format_exc
 
@@ -17,7 +18,6 @@ from galaxy.util import (
     parse_non_hex_float,
     unicodify
 )
-from galaxy.util.getargspec import getfullargspec
 from galaxy.util.json import safe_dumps
 from galaxy.web.framework import url_for
 
@@ -75,16 +75,22 @@ def json_pretty(func):
     return json(func, pretty=True)
 
 
-def require_login(verb="perform this action", use_panels=False, webapp='galaxy'):
+def require_login(verb="perform this action", use_panels=False):
     def argcatcher(func):
         @wraps(func)
         def decorator(self, trans, *args, **kwargs):
             if trans.get_user():
                 return func(self, trans, *args, **kwargs)
             else:
+                redirect_url = url_for(controller=trans.controller, action=trans.action)
+                query_string = trans.environ.get('QUERY_STRING', '')
+                if query_string:
+                    redirect_url = f"{redirect_url}?{query_string}"
+                href = url_for(controller='login', redirect=redirect_url)
                 return trans.show_error_message(
-                    'You must be <a target="galaxy_main" href="%s">logged in</a> to %s.'
-                    % (url_for(controller='user', action='login', webapp=webapp), verb), use_panels=use_panels)
+                    f'You must be <a target="galaxy_main" href="{href}">logged in</a> to {verb}.',
+                    use_panels=use_panels
+                )
         return decorator
     return argcatcher
 
@@ -216,14 +222,16 @@ def __extract_payload_from_request(trans, func, kwargs):
                 except Exception:
                     # may not actually be json, just continue
                     pass
+    elif content_type == 'application/offset+octet-stream':
+        return unicodify(trans.request.body)
     else:
         # Assume application/json content type and parse request body manually, since wsgi won't do it. However, the order of this check
         # should ideally be in reverse, with the if clause being a check for application/json and the else clause assuming a standard encoding
         # such as multipart/form-data. Leaving it as is for backward compatibility, just in case.
         payload = loads(unicodify(trans.request.body))
-        run_as = trans.request.headers.get('run-as')
-        if run_as:
-            payload['run_as'] = run_as
+    run_as = trans.request.headers.get('run-as')
+    if run_as:
+        payload['run_as'] = run_as
     return payload
 
 
